@@ -1,4 +1,4 @@
 from tsbot.bot import TSBot
 from tsbot.query_builder import query
 
-# pyright: reportUnusedImport=false
+__all__ = ("TSBot", "query")
