@@ -1,4 +1,4 @@
 from tsbot.commands.handler import CommandHandler
 from tsbot.commands.tscommand import TSCommand
 
-# pyright: reportUnusedImport=false
+__all__ = ("TSCommand", "CommandHandler")
