@@ -1,4 +1,4 @@
 from tsbot.default_plugins.help import Help
 from tsbot.default_plugins.keepalive import KeepAlive
 
-# pyright: reportUnusedImport=false
+__all__ = ("Help", "KeepAlive")
