@@ -49,6 +49,6 @@ class KeepAlive(plugin.TSPlugin):
     async def on_command_sent(self, bot: bot.TSBot, event: events.TSEvent) -> None:
         self.command_sent_event.set()
 
-    @plugin.on("run")
+    @plugin.once("run")
     async def register_keepalive_task(self, bot: bot.TSBot, event: events.TSEvent) -> None:
         bot.register_background_task(self._keep_alive_task, name="KeepAlive-Task")
